MidiMessage class

Implementers

Constructors

MidiMessage()
Base class for MIDI message types

Properties

data Uint8List
Byte data of the message
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateData() Uint8List
Generates MIDI bytes for this message without sending.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send({String? deviceId, int? timestamp}) → void
Send the message bytes to all connected devices
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(Uint8List bytes, {MidiMessageParser? parser, bool flushPendingNrpn = true}) List<MidiMessage>
Parses one or more raw MIDI messages into typed MidiMessage objects.