PCMessage class

Inheritance

Constructors

PCMessage({int channel = 0, int program = 0})
Program Change Message

Properties

channel int
getter/setter pair
data Uint8List
Byte data of the message
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
program int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateData() Uint8List
Generates MIDI bytes for this message without sending.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send({String? deviceId, int? timestamp}) → void
Send the message bytes to all connected devices
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited